@@ -42,9 +42,9 @@ class ARTIKULATECORE_EXPORT Phrase : public QObject
     Q_PROPERTY(QString soundFileUrl READ soundFileUrl NOTIFY soundChanged)
     Q_PROPERTY(Phrase::Type type READ type WRITE setType NOTIFY typeChanged)
     Q_PROPERTY(Phrase::EditState editState READ editState WRITE setEditState NOTIFY editStateChanged)
-    Q_PROPERTY(Phrase::TrainingState trainingState READ trainingState WRITE setTrainingState NOTIFY trainingStateChanged)
     Q_PROPERTY(Unit *unit READ unit NOTIFY unitChanged)
     Q_PROPERTY(bool excluded READ isExcluded NOTIFY excludedChanged)
+    Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
 public:
     Q_ENUMS(EditState)
     Q_ENUMS(TrainingState)
@@ -54,10 +54,14 @@ public:
         Translated,
         Completed
     };
-    enum TrainingState {
+    enum TrainingState { //TODO not needed anymore with statistics
         Trained,
         Untrained
     };
+    enum class Progress {
+        Skip,
+        Done
+    };
     enum Type {
         Word,
         Expression,
@@ -90,13 +94,14 @@ public:
     QString editStateString() const;
     void setEditState(Phrase::EditState state);
     void setEditState(const QString &stateString);
-    Phrase::TrainingState trainingState() const;
-    void setTrainingState(Phrase::TrainingState state);
     QUrl sound() const;
     void setSound(const QUrl &soundFile);
     QList<Phoneme *> phonemes() const;
     bool isExcluded() const;
     void setExcluded(bool excluded = false);
+    int progress() const;
+    void setProgress(int value);
+    void updateProgress(Phrase::Progress progress);
 
     Q_INVOKABLE bool hasPhoneme(Phoneme *phoneme);
     Q_INVOKABLE void addPhoneme(Phoneme *phoneme);
@@ -109,11 +114,11 @@ Q_SIGNALS:
     void i18nTextChanged();
     void typeChanged();
     void editStateChanged();
-    void trainingStateChanged();
     void soundChanged();
     void excludedChanged();
     void phonemesChanged();
     void modified();
+    void progressChanged();
 
 private:
     Q_DISABLE_COPY(Phrase)
@@ -123,8 +128,9 @@ private:
     QString m_i18nText;
     Type m_type;
     EditState m_editState;
-    TrainingState m_trainingState;
     Unit *m_unit;
+    unsigned m_trainingProgress;
+    int m_skipCounter; // count how many skips occured since last progress update
     bool m_excludedFromUnit;
     QList<Phoneme *> m_phonemes;
     QUrl m_nativeSoundFile;
